@@ -36,7 +36,6 @@ if(species_name == "SN") {
     #if(strip_bryophytes) {hits <- subset(hits, taxa_group != "bryophytes")}
     if(strip_bryophytes) {warning("Argument 'strip_bryophytes' is deprecated. species_name = 'HD' returns all determinations, whereas 'SN' returns matches with the Australian Plant Census, which excludes bryophytes.")}
     
-    
     hits <- hits[which(!duplicated(hits[,c("site_unique", "standardised_name"),])), c("site_unique", "standardised_name")] #remove duplicated hits (i.e. same species in a given plot - we just want binary presence/absence here)
     
     hits <- hits[!is.na(hits$standardised_name), ] #remove hots not determined as a species
@@ -315,7 +314,7 @@ if(species_name == "GS"){ #using genus species
 } # end genus_species
 
 
-return(species_matrix)
+return(round(species_matrix, digits=1))
 	
 } #end function
 
